@@ -893,6 +893,7 @@ printFiles::getNumericalOptions(numerical_opt_t **numerical_opts_arr)
            (*scan != '\n') && (*scan != '\0');
            scan ++) {
         switch(*scan) {
+          case '[': // open square bracket
           case '{': // open curled bracket
             if (!inquotes) {
               openbrackets ++;
@@ -901,7 +902,7 @@ printFiles::getNumericalOptions(numerical_opt_t **numerical_opts_arr)
               writepointer = item;
               // in which type of block are we now?
               if ((openbrackets == 2) && 
-                  (strcasecmp(item,"args_byname") == 0)) {
+                  (strncasecmp(item,"args",4) == 0)) {
                 // we are entering the arguments section now
                 inargspart = 1;
       	      }
@@ -915,6 +916,7 @@ printFiles::getNumericalOptions(numerical_opt_t **numerical_opts_arr)
             } else {*writepointer = *scan; writepointer ++;}
             break;
 	  case ',': // end of logical line
+          case ']': // close square bracket
 	  case '}': // close curled bracket
             if (!inquotes) {
               // right hand side completed, go to left hand side
@@ -922,6 +924,12 @@ printFiles::getNumericalOptions(numerical_opt_t **numerical_opts_arr)
               writepointer = item;
               // evaluate logical line
               if (item[0]) {
+                // Machine-readable argument name
+                if ((openbrackets == 3) &&
+                    (inargspart == 1) &&
+                    (strcasecmp(item,"name") == 0)) {
+                  strcpy(argname,value);
+                }
                 // Human-readable argument name
                 if ((openbrackets == 3) &&
                     (inargspart == 1) &&
@@ -956,8 +964,8 @@ printFiles::getNumericalOptions(numerical_opt_t **numerical_opts_arr)
                 // item already evaluated now
                 item[0] = '\0';
               }
-              // close curled bracket
-              if (*scan == '}') {
+              // close bracket
+              if ((*scan == '}') || (*scan == ']')) {
                 // which block did we complete now?
                 if ((openbrackets == 2) && 
                     (inargspart == 1)) {
@@ -1424,6 +1432,8 @@ printFiles::buildOptionWidgets()
   char          buffer[1024];   /* buffer for generating strings */
 //int           conflicting = 0;/* 1 in case of a conflict the current group */
   int           readonly;       /* 1 for readonly tab (Installed Options) */
+  int           isnumerical;    /* 1 when the option is a Foomatic numerical
+				   option */
   Fl_Group      *currentTab;    /* Tab where widgets are currently added.
                                    must be made red if current options
                                    conflicts. */
@@ -1487,6 +1497,18 @@ printFiles::buildOptionWidgets()
       {
         // Omit option "PageRegion"
         if (strcasecmp(option->keyword,"PageRegion") == 0) continue;
+	// Omit Foomatic numerical options, thay are treated separately
+	isnumerical = 0;
+	for (m = 0, num_option = numerical_opts[dest_pos]; 
+	     m < num_numerical_opts[dest_pos];
+	     m ++, num_option ++)
+	  {
+	    if (strcmp(option->keyword, num_option->keyword) == 0) {
+	      isnumerical = 1;
+	      break;
+	    }
+	  }
+	if (isnumerical == 1) continue;
         // Insert widget
         if (option->ui < 2) // BOOLEAN or PICKONE
 	{
@@ -2299,5 +2321,5 @@ sighandler(int s)	/* I - Signal number */
 
 
 /*
- * End of "$Id: xpp.cxx,v 1.16 2001/01/27 23:14:20 tillkamppeter Exp $".
+ * End of "$Id: xpp.cxx,v 1.19 2002/01/09 13:38:08 tillkamppeter Exp $".
  */
